@@ -31,7 +31,7 @@
 //!
 //! let pos: Chess = "8/8/8/8/B7/N7/K2k4/8 b - - 0 1"
 //!     .parse::<Fen>()?
-//!     .position(CastlingMode::Standard)?;
+//!     .into_position(CastlingMode::Standard)?;
 //!
 //! let wdl = tables.probe_wdl_after_zeroing(&pos)?;
 //! assert_eq!(wdl, Wdl::Loss);
@@ -54,11 +54,10 @@
 //!   This may be useful to identify issues with corrupted tablebase files or
 //!   to debug the probing code. Currently requires nightly Rust.
 
-#![doc(html_root_url = "https://docs.rs/shakmaty-syzygy/0.18.0")]
+#![doc(html_root_url = "https://docs.rs/shakmaty-syzygy/0.19.0")]
 #![forbid(unsafe_code)]
 #![warn(missing_docs)]
 #![warn(missing_debug_implementations)]
-#![warn(rust_2018_idioms)]
 #![cfg_attr(docs_rs, feature(doc_cfg))]
 #![cfg_attr(feature = "backtrace", feature(backtrace))]
 
@@ -75,6 +74,7 @@ pub use crate::table::{DtzTable, WdlTable};
 pub use crate::types::DecisiveWdl;
 pub use crate::{
     errors::{ProbeError, SyzygyError},
+    material::Material,
     tablebase::Tablebase,
     types::{AmbiguousWdl, Dtz, MaybeRounded, Metric, Syzygy, TableType, Wdl},
 };
